﻿Public Class Form1
    ' Save the original image.
    Private OriginalImage, ShadedImage As Bitmap
    Private SmallWidth, SmallHeight As Integer
    Private ScaleX, ScaleY As Single

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        OriginalImage = DirectCast(picWhole.Image, Bitmap)
        picCloseup.Image = OriginalImage
        picCloseup.SizeMode = PictureBoxSizeMode.AutoSize

        ' Make a shaded version of the image.
        ShadedImage = New Bitmap(OriginalImage)
        Using gr As Graphics = Graphics.FromImage(ShadedImage)
            Using br As New SolidBrush(Color.FromArgb(128, 255, 255, 255))
                Dim rect As New Rectangle(0, 0, ShadedImage.Width, ShadedImage.Height)
                gr.FillRectangle(br, rect)
            End Using
        End Using

        ' Get scale factors to map from big scale to small scale.
        ScaleX = CSng(panCloseup.ClientSize.Width) / OriginalImage.Width
        ScaleY = CSng(panCloseup.ClientSize.Height) / OriginalImage.Height

        ' See how big the closeup is on the small scale.
        SmallWidth = CInt(ScaleX * picWhole.ClientSize.Width)
        SmallHeight = CInt(ScaleY * picWhole.ClientSize.Height)
    End Sub

    ' Go to the Astronomy Picture of the Day web site.
    Private Sub linkLabel1_LinkClicked(ByVal sender As System.Object, ByVal e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkLabel1.LinkClicked
        System.Diagnostics.Process.Start("http:'antwrp.gsfc.nasa.gov/apod/ap090628.html")
    End Sub

    ' Display a closeup of this area.
    Private ViewingRectangle As Rectangle

    Private Sub picWhole_MouseMove(ByVal sender As System.Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles picWhole.MouseMove
        ' Position picCloseup inside its parent Panel.
        Dim x As Single = CSng(e.X) / picWhole.ClientSize.Width * OriginalImage.Width - CSng(panCloseup.ClientSize.Width) / 2
        Dim y As Single = CSng(e.Y) / picWhole.ClientSize.Height * OriginalImage.Height - CSng(panCloseup.ClientSize.Height) / 2
        If (x < 0) Then x = 0
        If (y < 0) Then y = 0
        If (x > OriginalImage.Width - panCloseup.ClientSize.Width) Then
            x = OriginalImage.Width - panCloseup.ClientSize.Width
        End If
        If (y > OriginalImage.Height - panCloseup.ClientSize.Height) Then
            y = OriginalImage.Height - panCloseup.ClientSize.Height
        End If
        picCloseup.Location = New Point(-CInt(x), -CInt(y))

        ' Record the position we are viewing.
        ViewingRectangle = New Rectangle(CInt(x), CInt(y), _
            panCloseup.ClientSize.Width, _
            panCloseup.ClientSize.Height)

        ' Draw the closeup area.
        picWhole.Invalidate()
    End Sub

    ' Draw the viewing area.
    Private Sub picWhole_Paint(ByVal sender As System.Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles picWhole.Paint
        ' Scale so we can draw in the full scale coordinates.
        e.Graphics.ScaleTransform(ScaleX, ScaleY)

        ' Draw the viewing area using the original image.
        e.Graphics.DrawImage(OriginalImage, ViewingRectangle, _
            ViewingRectangle, GraphicsUnit.Pixel)
        'e.Graphics.DrawRectangle(Pens.Red, ViewingRectangle)
    End Sub

    ' Use the shaded background image.
    Private Sub picWhole_MouseEnter(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles picWhole.MouseEnter
        picWhole.Image = ShadedImage
        panCloseup.Visible = True
    End Sub

    ' Use the regular image.
    Private Sub picWhole_MouseLeave(ByVal sender As Object, ByVal e As System.EventArgs) Handles picWhole.MouseLeave
        picWhole.Image = OriginalImage
        panCloseup.Visible = False
    End Sub
End Class
